==> libosmo-sccp_1.5.0.tar.xz: BUILD/README.md <==
libosmo-sccp - Osmocom SCCP, SIGTRAN and STP
============================================

This repository contains a C-language library implementation of a
variety of telecom signaling protocols, such as M3UA, SUA, SCCP
(connection oriented and connectionless), as well as the OsmoSTP, a SS7
Transfer Point.

Homepage
--------

The official homepage of libosmo-sccp is
	https://osmocom.org/projects/libosmo-sccp/wiki

The official homepage of osmo-stp is
	https://osmocom.org/projects/osmo-stp/wiki

GIT Repository
--------------

You can clone from the official git repository using

	git clone git://git.osmocom.org/libosmo-sccp.git
	git clone https://git.osmocom.org/libosmo-sccp.git

There is a cgit interface at https://git.osmocom.org/libosmo-sccp/

Documentation
-------------

User Manuals and VTY reference manuals are [optionally] built in PDF form
as part of the build process.

Pre-rendered PDF version of the current "master" can be found at
[User Manual](https://ftp.osmocom.org/docs/latest/osmostp-usermanual.pdf)
as well as the VTY reference manuals
* [VTY Reference Manual for osmo-stp](https://ftp.osmocom.org/docs/latest/osmostp-vty-reference.pdf)

Mailing List
------------

Discussions related to osmo-stp are happening on the
openbsc@lists.osmocom.org mailing list, please see
https://lists.osmocom.org/mailman/listinfo/openbsc for subscription
options and the list archive.

Please observe the [Osmocom Mailing List
Rules](https://osmocom.org/projects/cellular-infrastructure/wiki/Mailing_List_Rules)
when posting.

Contributing
------------

Our coding standards are described at
https://osmocom.org/projects/cellular-infrastructure/wiki/Coding_standards

We us a gerrit based patch submission/review process for managing
contributions.  Please see
https://osmocom.org/projects/cellular-infrastructure/wiki/Gerrit for
more details

The current patch queue can be seen at
https://gerrit.osmocom.org/#/q/project:libosmo-sccp+status:open

==> libosmo-sccp_1.7.1.tar.xz: BUILD/README.md <==
libosmo-sccp - Osmocom SCCP, SIGTRAN and STP
============================================

This repository contains a C-language library implementation of a
variety of telecom signaling protocols, such as M3UA, SUA, SCCP
(connection oriented and connectionless), as well as the OsmoSTP, a SS7
Transfer Point.

Homepage
--------

The official homepage of libosmo-sccp is
	https://osmocom.org/projects/libosmo-sccp/wiki

The official homepage of osmo-stp is
	https://osmocom.org/projects/osmo-stp/wiki

GIT Repository
--------------

You can clone from the official git repository using

	git clone https://gitea.osmocom.org/osmocom/libosmo-sccp

There is a web interface at <https://gitea.osmocom.org/osmocom/libosmo-sccp>

Documentation
-------------

User Manuals and VTY reference manuals are [optionally] built in PDF form
as part of the build process.

Pre-rendered PDF version of the current "master" can be found at
[User Manual](https://ftp.osmocom.org/docs/latest/osmostp-usermanual.pdf)
as well as the VTY reference manuals
* [VTY Reference Manual for osmo-stp](https://ftp.osmocom.org/docs/latest/osmostp-vty-reference.pdf)

Mailing List
------------

Discussions related to osmo-stp are happening on the
openbsc@lists.osmocom.org mailing list, please see
https://lists.osmocom.org/mailman/listinfo/openbsc for subscription
options and the list archive.

Please observe the [Osmocom Mailing List
Rules](https://osmocom.org/projects/cellular-infrastructure/wiki/Mailing_List_Rules)
when posting.

Contributing
------------

Our coding standards are described at
https://osmocom.org/projects/cellular-infrastructure/wiki/Coding_standards

We us a gerrit based patch submission/review process for managing
contributions.  Please see
https://osmocom.org/projects/cellular-infrastructure/wiki/Gerrit for
more details

The current patch queue can be seen at
https://gerrit.osmocom.org/#/q/project:libosmo-sccp+status:open
